@@ -1,6 +1,5 @@
 #![allow(clippy::needless_return)]
 
-extern crate text_utils;
 mod command;
 mod errors;
 pub mod nodes;
@@ -8,3 +7,8 @@ pub mod traits;
 
 pub use errors::{NoteError, Result};
 pub use nodes::{ASTKind, ASTNode, ASTNodes};
+
+pub mod utils {
+    pub use yggdrasil_shared::records::*;
+    pub use text_utils::*;
+}
\ No newline at end of file
